@@ -97,6 +97,9 @@ class _Marshaller:
         self.python_version = python_version
 
     def dump(self, x):
+        if isinstance(x, types.CodeType) and PYTHON_VERSION != self.version:
+            raise RuntimeError("code type passed for version %s but we are running version %s" %
+                               (PYTHON_VERSION, self.version))
         try:
             self.dispatch[type(x)](self, x)
         except KeyError:
@@ -1030,22 +1033,32 @@ def dumps(x, version=version, python_version=None):
     m = _Marshaller(buffer.append, python_version=python_version)
     m.dump(x)
     if python_version:
-        is_python3 = python_version >= "3.0"
+        is_python3 = python_version >= 3.0
     else:
         is_python3 = PYTHON3
 
     if is_python3:
-        buf = []
-        for b in buffer:
-            if isinstance(b, str) and PYTHON3:
-                s2b = bytes(ord(b[j]) for j in range(len(b)))
-                buf.append(s2b)
-            elif isinstance(b, bytearray):
-                buf.append(str(b))
-            else:
-                buf.append(b)
-        return b"".join(buf)
+        if PYTHON_VERSION >= 3.0:
+            # Python 3.x handling  Python 3.x
+            buf = []
+            for b in buffer:
+                if isinstance(b, str) and PYTHON3:
+                    s2b = bytes(ord(b[j]) for j in range(len(b)))
+                    buf.append(s2b)
+                elif isinstance(b, bytearray):
+                    buf.append(str(b))
+                else:
+                    buf.append(b)
+            return b"".join(buf)
+        else:
+            # Python 2.x handling Python 3.x
+            buf = b""
+            for b in buffer:
+                buf += b.decode(errors="ignore")
+                pass
+            return buf
     else:
+        # Python 2 or 3 handling Python 2.x
         buf = []
         for b in buffer:
             if isinstance(b, bytes):
