@@ -120,7 +120,9 @@ op_imports = {
     '3.8' : opcode_38,
     '3.9.0alpha1' : opcode_39,
     '3.9.0alpha2' : opcode_39,
+    '3.9.0beta5' : opcode_39,
     '3.9' : opcode_39,
+    3.9 : opcode_39,
 
     '2.6pypy':  opcode_26pypy,
     '2.7pypy':  opcode_27pypy,
