@@ -113,7 +113,6 @@ def load_code(fp, magic_int, code_objects={}):
         internObjects[0] = code
     return code
 
-
 def load_code_type(fp, magic_int, bytes_for_s=False, code_objects={}):
     # FIXME: use tables to simplify this?
     # FIXME: Python 1.0 .. 1.3 isn't well known
@@ -166,7 +165,11 @@ def load_code_type(fp, magic_int, bytes_for_s=False, code_objects={}):
     co_code = load_code_internal(
         fp, magic_int, bytes_for_s=True, code_objects=code_objects
     )
-    co_consts = load_code_internal(fp, magic_int, code_objects=code_objects)
+
+    bytes_for_s = PYTHON_VERSION >= 3.0 and version >= 3.0
+    co_consts = load_code_internal(fp, magic_int,
+                                   bytes_for_s=bytes_for_s,
+                                   code_objects=code_objects)
     co_names = load_code_internal(fp, magic_int, code_objects=code_objects)
 
     if version >= 1.3:
@@ -460,7 +463,7 @@ def t_small_tuple(fp, save_ref, bytes_for_s=None, magic_int=None, code_objects=N
     tuplesize = unpack("B", fp.read(1))[0]
     ret, i = r_ref_reserve(tuple(), save_ref)
     while tuplesize > 0:
-        ret += (load_code_internal(fp, magic_int, code_objects=code_objects),)
+        ret += (load_code_internal(fp, magic_int, bytes_for_s=bytes_for_s, code_objects=code_objects),)
         tuplesize -= 1
         pass
     return r_ref_insert(ret, i)
@@ -473,7 +476,7 @@ def t_tuple(fp, save_ref, bytes_for_s=None, magic_int=None, code_objects=None):
     tuplesize = unpack("<i", fp.read(4))[0]
     ret = r_ref(tuple(), save_ref)
     while tuplesize > 0:
-        ret += (load_code_internal(fp, magic_int, code_objects=code_objects),)
+        ret += (load_code_internal(fp, magic_int, bytes_for_s=bytes_for_s, code_objects=code_objects),)
         tuplesize -= 1
     return ret
 
@@ -486,7 +489,7 @@ def t_list(fp, save_ref, bytes_for_s=None, magic_int=None, code_objects=None):
     n = unpack("<i", fp.read(4))[0]
     ret = r_ref(list(), save_ref)
     while n > 0:
-        ret += (load_code_internal(fp, magic_int, code_objects=code_objects),)
+        ret += (load_code_internal(fp, magic_int, bytes_for_s=bytes_for_s, code_objects=code_objects),)
         n -= 1
     return ret
 
@@ -498,7 +501,7 @@ def t_frozenset(fp, save_ref, bytes_for_s=None, magic_int=None, code_objects=Non
     setsize = unpack("<i", fp.read(4))[0]
     ret, i = r_ref_reserve(tuple(), save_ref)
     while setsize > 0:
-        ret += (load_code_internal(fp, magic_int, code_objects=code_objects),)
+        ret += (load_code_internal(fp, magic_int, bytes_for_s=bytes_for_s, code_objects=code_objects),)
         setsize -= 1
     return r_ref_insert(frozenset(ret), i)
 
@@ -510,7 +513,7 @@ def t_set(fp, save_ref, bytes_for_s=None, magic_int=None, code_objects=None):
     setsize = unpack("<i", fp.read(4))[0]
     ret, i = r_ref_reserve(tuple(), save_ref)
     while setsize > 0:
-        ret += (load_code_internal(fp, magic_int, code_objects=code_objects),)
+        ret += (load_code_internal(fp, magic_int, bytes_for_s=bytes_for_s, code_objects=code_objects),)
         setsize -= 1
     return r_ref_insert(set(ret), i)
 
@@ -526,18 +529,19 @@ UNMARSHAL_DISPATCH_TABLE["i"] = t_int32
 
 
 def t_dict(fp, save_ref, bytes_for_s=None, magic_int=None, code_objects=None):
-    ret = r_ref(dict(), save_ref)
+    # ret = r_ref(dict(), save_ref)
     # dictionary
     # while True:
-    #     key = load_code_internal(fp, magic_int, code_objects=code_objects)
+    #     key = load_code_internal(fp, magic_int, bytes_for_s=bytes_for_s, code_objects=code_objects)
     #     if key is NULL:
     #         break
-    #     val = load_code_internal(fp, magic_int, code_objects=code_objects)
+    #     val = load_code_internal(fp, magic_int, byte_for_s=bytes_for_s, code_objects=code_objects)
     #     if val is NULL:
     #         break
     #     ret[key] = val
     #     pass
-    raise KeyError(marshalType)
+    # raise KeyError(marshalType)
+    raise KeyError("marshaltype key '{' (dict) not implemented")
 
 
 UNMARSHAL_DISPATCH_TABLE["{"] = t_dict
@@ -577,7 +581,7 @@ UNMARSHAL_DISPATCH_TABLE["r"] = t_object_reference
 
 
 def t_unknown(fp, save_ref=None, bytes_for_s=None, magic_int=None, code_objects=None):
-    raise KeyError(marshalType)
+    raise KeyError("unknown marshal type '?'")
 
 
 UNMARSHAL_DISPATCH_TABLE["?"] = t_unknown
